@@ -115,13 +115,12 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
     def _do_request_no_api(self, cmd):
         """Perform a get in the context of enabling the API."""
         url = "https://{}:{}/{}".format(self.ip_address, self.port, cmd)
-        if self.cert:
-            resp = self._tls_session.get(url, verify=False, timeout=utils.TIMEOUT,
-                                         cert=self.cert)
-        else:
-            resp = self._tls_session.get(url, verify=False, timeout=utils.TIMEOUT,
-                                         auth=(self.username, self.password))
-            self._tls_session.close()
+        # If a cert is supplied, auth will be none
+        # otherwise, auth will be auth_handler(username, password)
+        auth = self._get_basic_auth()
+        resp = self._tls_session.get(url, verify=False, timeout=utils.TIMEOUT,
+                                     cert=self.cert, auth=auth)
+        self._tls_session.close()
         return resp.status_code
 
     @property
